#ifndef WESTERNLANGUAGESPLUGIN_H
#define WESTERNLANGUAGESPLUGIN_H

#include "languageplugininterface.h"
#include "candidatescallback.h"
#include "westernlanguagefeatures.h"
#include "spellchecker.h"
#include "abstractlanguageplugin.h"

#include <presage.h>

#include <QObject>

class WesternLanguageFeatures;
class CandidatesCallback;

class WesternLanguagesPlugin : public AbstractLanguagePlugin
{
    Q_OBJECT
    Q_INTERFACES(LanguagePluginInterface)

public:
    explicit WesternLanguagesPlugin(QObject *parent = 0);
    virtual ~WesternLanguagesPlugin();

    virtual void predict(const QString& surroundingLeft, const QString& preedit);
    virtual void wordCandidateSelected(QString word);
    virtual AbstractLanguageFeatures* languageFeature();

    //! spell checker
    virtual bool spellCheckerEnabled();
    virtual bool setSpellCheckerEnabled(bool enabled);
    virtual bool spell(const QString& word);
    virtual void spellCheckerSuggest(const QString& word, int limit);
    virtual void addToSpellCheckerUserWordList(const QString& word);
    virtual bool setSpellCheckerLanguage(const QString& languageId);

signals:
    void newSpellingSuggestions(QStringList suggestions);
    void newPredictionSuggestions(QStringList suggestions);
    void newSpellCheckWord(QString word);
    void setSpellCheckLimit(int limit);
    void setSpellCheckLanguage(QString language);
    void spellCheckEnabled(bool enabled);
    void parsePredictionText(QString surroundingLeft, QString preedit);
    void setPredictionLanguage(QString language);
    void updateSpellCheckWord(QString word);

public slots:

private:
    WesternLanguageFeatures* m_languageFeatures;

    SpellChecker m_spellChecker;
    QThread *m_spellCheckThread;
    QThread *m_predictiveTextThread;
};

#endif // WESTERNLANGUAGESPLUGIN_H
